@@ -23,9 +23,11 @@ class ZigbeeMqttPlugin(MqttPlugin, SwitchPlugin):
     Instructions:
 
         - Install `cc-tool <https://github.com/dashesy/cc-tool>`_ either from sources or from a package manager.
-        - Connect the Zigbee to your PC/RaspberryPi in this way:
+        - Connect the Zigbee to your PC/RaspberryPi in this way: ::
+
             USB -> CC debugger -> downloader cable -> CC2531 -> USB
-          The debugger and the adapter should be connected *at the same time*. If the later ``cc-tool`` command throws
+
+        - The debugger and the adapter should be connected *at the same time*. If the later ``cc-tool`` command throws
           up an error, put the device in sync while connected by pressing the _Reset_ button on the debugger.
         - Check where the device is mapped. On Linux it will usually be ``/dev/ttyACM0``.
         - Download the latest `Z-Stack firmware <https://github.com/Koenkk/Z-Stack-firmware/tree/master/coordinator>`_
@@ -122,7 +124,6 @@ class ZigbeeMqttPlugin(MqttPlugin, SwitchPlugin):
         :param username: If the connection requires user authentication, specify the username (default: None)
         :param password: If the connection requires user authentication, specify the password (default: None)
         """
-
         super().__init__(host=host, port=port, tls_certfile=tls_certfile, tls_keyfile=tls_keyfile,
                          tls_version=tls_version, tls_ciphers=tls_ciphers, username=username,
                          password=password, **kwargs)
@@ -195,19 +196,6 @@ class ZigbeeMqttPlugin(MqttPlugin, SwitchPlugin):
             except Exception as e:
                 self.logger.warning('Error on MQTT client disconnection: {}'.format(str(e)))
 
-    def _mqtt_args(self, **kwargs):
-        return {
-            'host': kwargs.get('host', self.host),
-            'port': kwargs.get('port', self.port),
-            'timeout': kwargs.get('timeout', self.timeout),
-            'tls_certfile': kwargs.get('tls_certfile', self.tls_certfile),
-            'tls_keyfile': kwargs.get('tls_keyfile', self.tls_keyfile),
-            'tls_version': kwargs.get('tls_version', self.tls_version),
-            'tls_ciphers': kwargs.get('tls_ciphers', self.tls_ciphers),
-            'username': kwargs.get('username', self.username),
-            'password': kwargs.get('password', self.password),
-        }
-
     def _topic(self, topic):
         return self.base_topic + '/' + topic
 
